@@ -21,6 +21,12 @@ RUNDIR = os.getenv('APP_RUNDIR', '/opt/app')
 LIBDIR = os.getenv('APP_LIBDIR',
     os.path.join(RUNDIR, 'lib'))
 
+#: RSA private key that is used for SSL in local development.
+LOCALHOST_SSL_KEY = os.getenv('LOCALHOST_SSL_KEY')
+
+#: X.509 certificate that is used for SSL in local development.
+LOCALHOST_SSL_CRT = os.getenv('LOCALHOST_SSL_CRT')
+
 PKIDIR = os.getenv('APP_PKIDIR',
     os.path.join(RUNDIR, 'pki'))
 
