@@ -55,6 +55,26 @@ DEFAULTS = {
 
 class DataSourceName(dsnparse.ParseResult):
 
+    @property
+    def admin(self) -> str:
+        """Return the DSN used for an administrative connection (e.g. to
+        create a new database if it does not exist yet).
+        """
+        return self.replace(path='')
+
+    @property
+    def name(self) -> str:
+        return str.lstrip(self.path or '', '/') or None
+
+    @property
+    def test(self) -> str:
+        """Return the DSN for a transient testing database connection."""
+        if self.scheme == 'sqlite':
+            return DataSourceName('sqlite://')
+        if self.name is None:
+            raise ValueError("Must specify a database name.")
+        return self.replace(path=self.generate_test_name())
+
     @classmethod
     def verify(cls, dsn):
         pass
@@ -66,23 +86,39 @@ class DataSourceName(dsnparse.ParseResult):
             hostloc = '{hostloc}:{port}'.format(hostloc=hostloc, port=self.port)
         return hostloc or 'localhost'
 
-    def create_connection(self, from_dsn):
-        """Create a new connection instance using the factory function
-        `from_dsn`.
+    def generate_test_name(self) -> str:
+        """Return a string containing a unique name for a transient testing
+        database.
         """
-        return from_dsn(self.geturl())
+        return f'test_{bytes.hex(os.urandom(3))}'
+
+    def replace(self, **kwargs):
+        """Replace the parameters specified in the keyword arguments and
+        return a new instance.
+        """
+        scheme = kwargs.setdefault('scheme', self.scheme)
+        hostname = kwargs.setdefault('hostname', self.hostname)
+        params = self.parse(self.geturl())
+        params.pop('dsn')
+        return dsnparse.parse(
+            f'{scheme}://{hostname}',
+            parse_class=type(self), **{**params, **kwargs})
 
 
 def encode_dsn(opts: DTO) -> str:
     """Encodes the database configuration into a Data Source Name (DSN)."""
-    dsn = dsnparse.parse(f'{opts.engine}://{opts.host}', DataSourceName)
+    dsn = dsnparse.parse(f'{opts.engine}://', DataSourceName)
     if opts.engine == 'sqlite':
+        if opts.host is None:
+            dsn.setdefault('hostname', '/')
         if opts.get('name') not in (':mem:', ':memory:', None):
             dsn.setdefault('hostname', opts.name)
     else:
         dsn.setdefault('username', opts.get('username') or '')
         dsn.setdefault('password', opts.get('password') or '')
         dsn.setdefault('path', opts.get('name') or '')
+        if opts.host is not None:
+            dsn.setdefault('hostname', opts.host)
 
     if opts.engine == 'postgresql':
         dsn.setdefault('port', opts.get('port') or 5432)
@@ -94,6 +130,8 @@ def encode_dsn(opts: DTO) -> str:
         pass
     else:
         raise NotImplementedError(opts.engine)
+    if opts.engine != 'sqlite':
+        assert dsn.hostname is not None
     return dsn
 
 
